==> galaxy-ng-4.2.0a12.tar.gz: galaxy-ng-4.2.0a12/README.md <==
# Galaxy NG

[![Build Status](https://travis-ci.com/ansible/galaxy_ng.svg?branch=master)](https://travis-ci.com/ansible/galaxy_ng)

A Pulp plugin to support hosting your very own Ansible Galaxy server.

This is a brand new take on Ansible Galaxy, so it will look and feel a bit different than the current [galaxy.ansible.com web site](https://galaxy.ansible.com). Over time we expect to migrate the web site to this codebase, so for now you're looking into the future, and you have an opportunity to help shape that future.

Our mission is to help organizations share Ansible automation and promote a culture of collaboration around Ansible automation development. We'll be providing features that make it easy to create, discover, use and distribute Ansible automation content.

To see what we're currently working on, [view the Roadmap](/ROADMAP.rst). 

To learn more about Pulp, [view the Pulp project page](https://pulpproject.org/).

## OpenAPI Spec

View the latest version of the spec by [clicking here](https://petstore.swagger.io/?url=https://raw.githubusercontent.com/ansible/galaxy_ng/master/openapi/openapi.yaml).

## Contributing

* If you're interested in jumping in and helping out, [view the contributing guide](https://github.com/ansible/galaxy_ng/wiki#contributing-to-galaxyng).
* To setup your development environment, [view the development setup guide](https://github.com/ansible/galaxy_ng/wiki/Development-Setup).
* Chat with us on irc.freenode.net: #ansible-galaxy
* Found a bug or have a feature idea? Please [open an issue](https://github.com/ansible/galaxy_ng/issues/new/choose).

## Installation

To install and run a local GalaxyNG server [view the End User Installation guide](https://github.com/ansible/galaxy_ng/wiki/End-User-Installation).

# License

GNU General Public License v2. View [LICENSE](/LICENSE) for full text.

==> galaxy-ng-4.7.0.tar.gz: galaxy-ng-4.7.0/README.md <==
# Galaxy NG

[![Build Status](https://github.com/ansible/galaxy_ng/actions/workflows/ci.yml/badge.svg)](https://github.com/ansible/galaxy_ng/actions/workflows/ci.yml)

A Pulp plugin to support hosting your very own Ansible Galaxy server.

This is a brand new take on Ansible Galaxy, so it will look and feel a bit different than the current [galaxy.ansible.com web site](https://galaxy.ansible.com). Over time we expect to migrate the web site to this codebase, so for now you're looking into the future, and you have an opportunity to help shape that future.

Our mission is to help organizations share Ansible automation and promote a culture of collaboration around Ansible automation development. We'll be providing features that make it easy to create, discover, use and distribute Ansible automation content.

To see what we're currently working on, [view the Roadmap](/ROADMAP.rst). 

To learn more about Pulp, [view the Pulp project page](https://pulpproject.org/).

## Documentation

Project documentation is hosted on [netlify](https://galaxyng.netlify.app/).

## OpenAPI Spec

View the latest version of the spec by [clicking here](https://petstore.swagger.io/?url=https://raw.githubusercontent.com/ansible/galaxy_ng/master/openapi/openapi.yaml).

## Contributing

* If you're interested in jumping in and helping out, [view the contributing guide](https://github.com/ansible/galaxy_ng/wiki#contributing-to-galaxyng).
* To setup your development environment, [view the development setup guide](https://github.com/ansible/galaxy_ng/wiki/Development-Setup).
* Chat with us on irc.libera.chat: #ansible-galaxy
* Found a bug or have a feature idea? Please [open an issue](https://issues.redhat.com/projects/AAH/issues).

## Installation

To install and run a local GalaxyNG server [view the End User Installation guide](https://github.com/ansible/galaxy_ng/wiki/End-User-Installation).

# License

GNU General Public License v2. View [LICENSE](/LICENSE) for full text.
